@@ -232,12 +232,17 @@ class DataTracker:
         """ Unique 'key' for the tracker """
         self.category: str = self.key.lstrip('specialEvent_')
         """
-        Aggregate key for combining 'specialEvent' data with regular data
+        Aggregate key for combining 'specialEvent' and 'season' data with regular data
 
         Note:
             Special Event data is the same as regular but has a different key for
-            statistical purposes it makes sense to just drop the 'specialEvent' prefix.
+            statistical purposes it makes sense to just drop the 'specialEvent' prefix
+            or any 'season' suffix
         """
+        if self.category.startswith('wins_'):
+            self.category = 'wins'
+        if self.category.startswith('kills_'):
+            self.category = 'kills'
         rank_dict: dict = data_trackers_dict.get('rank')
         if not rank_dict:
             rank_dict = {'rankPos': -1, 'topPercent': -1.0}
